import 'package:flutter/material.dart';

class CustomCupertinoDialog extends StatelessWidget {
  final EdgeInsets margin;
  final EdgeInsets contentPadding;
  final Text? title;
  final Text content;
  final String? cancelText;
  final String? confirmText;
  final TextStyle cancelTextStyle;
  final TextStyle confirmTextStyle;
  final Function? onCancel;
  final Function? onConfirm;

  const CustomCupertinoDialog({
    Key? key,
    this.margin = const EdgeInsets.symmetric(horizontal: 36),
    this.contentPadding = const EdgeInsets.fromLTRB(16, 24, 16, 16),
    this.title,
    required this.content,
    this.cancelText,
    this.confirmText,
    this.cancelTextStyle = const TextStyle(color: Color(0xFF777777), fontSize: 18),
    this.confirmTextStyle = const TextStyle(color: Color(0xFF1989FA), fontSize: 18, fontWeight: FontWeight.bold),
    this.onCancel,
    this.onConfirm,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final hasCancelItem = cancelText != null && cancelText!.isNotEmpty;
    final hasConfirmItem = confirmText != null && confirmText!.isNotEmpty;
    return Dialog(
      backgroundColor: Colors.transparent,
      insetPadding: margin,
      child: Container(
        decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.all(Radius.circular(8)),
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            Container(
              padding: contentPadding,
              child: Column(
                children: [
                  Visibility(
                    visible: title != null,
                    child: title != null ? title! : Container(color: Colors.transparent),
                  ),
                  Visibility(
                    visible: title != null,
                    child: SizedBox(height: 16),
                  ),
                  content,
                ],
              ),
            ),
            Divider(height: 1, color: Color(0xFFE7E7E7)),
            Container(
              height: 48,
              child: Row(
                children: [
                  Visibility(
                    visible: hasCancelItem,
                    child: Expanded(
                      child: GestureDetector(
                        child: Container(
                          color: Colors.transparent,
                          alignment: Alignment.center,
                          child: Text(
                            cancelText ?? '',
                            style: cancelTextStyle,
                          ),
                        ),
                        onTap: onCancel as void Function()?,
                      ),
                    ),
                  ),
                  Visibility(
                    visible: hasCancelItem && hasConfirmItem,
                    child: VerticalDivider(width: 1, color: Color(0xFFE7E7E7)),
                  ),
                  Visibility(
                    visible: hasConfirmItem,
                    child: Expanded(
                      child: GestureDetector(
                        child: Container(
                          color: Colors.transparent,
                          alignment: Alignment.center,
                          child: Text(
                            confirmText ?? '',
                            style: confirmTextStyle,
                          ),
                        ),
                        onTap: onConfirm as void Function()?,
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
