import 'package:flutter/material.dart';
import 'package:get/get.dart';

class FilterDrawerContainer extends StatelessWidget {
  final String? title;
  final List<Widget> children;
  final VoidCallback? onReset;
  final VoidCallback? onConfirm;
  final Color themeColor;

  FilterDrawerContainer(
      {this.title, required this.children, this.onConfirm, this.onReset, this.themeColor = const Color(0xFFEC6D20)});

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          color: Colors.white,
          child: CustomScrollView(
            slivers: [
              SliverAppBar(
                leading: Stack(
                  alignment: Alignment.centerLeft,
                  children: [
                    Padding(
                      padding: EdgeInsets.only(left: 16),
                      child: Text(
                        title ?? 'Filter'.tr,
                        style: TextStyle(color: Color(0xFF222222), fontSize: 16, fontWeight: FontWeight.bold),
                        textAlign: TextAlign.center,
                      ),
                    )
                  ],
                ),
                leadingWidth: 100,
                pinned: true,
                actions: [
                  IconButton(
                      icon: Icon(
                        Icons.close,
                        size: 24,
                        color: Color(0xFF222222),
                      ),
                      onPressed: () {
                        Navigator.of(context).pop();
                      })
                ],
                elevation: 4,
                backgroundColor: Colors.white,
                bottom: PreferredSize(preferredSize: Size(double.infinity, 1), child: Divider(height: 1)),
              ),
              // -------- Content ---------
              SliverPadding(
                padding: EdgeInsets.only(left: 16, right: 16, top: 24, bottom: 120),
                sliver: SliverToBoxAdapter(
                  child: Column(
                    children: children,
                    crossAxisAlignment: CrossAxisAlignment.stretch,
                  ),
                ),
              )
            ],
          ),
        ),
        Positioned(
          child: Row(
            children: [
              Expanded(
                child: TextButton.icon(
                  style: TextButton.styleFrom(backgroundColor: Colors.white),
                  label: Text('reset'.tr, style: TextStyle(color: themeColor, fontSize: 15)),
                  icon: Icon(Icons.refresh, size: 20, color: themeColor),
                  onPressed: onReset,
                ),
              ),
              SizedBox(width: 12),
              Expanded(
                child: ElevatedButton(
                    child: Text('confirm'.tr,
                        style: TextStyle(color: Colors.white, fontSize: 15, fontWeight: FontWeight.w700)),
                    style: ButtonStyle(
                      backgroundColor: MaterialStateProperty.all(themeColor),
                      shape: MaterialStateProperty.all(RoundedRectangleBorder(borderRadius: BorderRadius.circular(4))),
                    ),
                    onPressed: onConfirm),
              ),
            ],
          ),
          bottom: 40,
          left: 16,
          right: 16,
        )
      ],
    );
  }
}
