import 'package:flutter/material.dart';
import 'package:get/get.dart';

class MultiSelectOption {
  final String name;
  bool isSelected;
  final dynamic rawValue;

  MultiSelectOption({required this.name, required this.isSelected, this.rawValue});
}

class MultiSelectBottomDialog extends StatefulWidget {
  final String title;
  final List<MultiSelectOption> options;
  final Color themeColor;

  MultiSelectBottomDialog({this.title = '', this.options = const [], this.themeColor = const Color(0xFFEC6D20)});

  @override
  _MultiSelectBottomDialogState createState() => _MultiSelectBottomDialogState();
}

class _MultiSelectBottomDialogState extends State<MultiSelectBottomDialog> {
  Widget _makeListItem(MultiSelectOption option, int idx) {
    return RawMaterialButton(
        onPressed: () async {
          setState(() {
            option.isSelected = !option.isSelected;
          });
          // await Future.delayed(Duration(milliseconds: 300));
          // Navigator.of(context).pop(idx);
        },
        constraints: BoxConstraints(minHeight: 44, maxHeight: 44),
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 32),
          child: Row(
            children: [
              Container(
                width: 20,
                height: 20,
                child: Checkbox(
                    value: option.isSelected,
                    activeColor: widget.themeColor,
                    onChanged: (bool? changed) {
                      setState(() {
                        option.isSelected = !option.isSelected;
                      });
                    }),
              ),
              SizedBox(
                width: 12,
              ),
              Expanded(
                child: Text(option.name, style: TextStyle(color: Color(0xFF222222), fontSize: 15)),
              )
            ],
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
          ),
        ));
  }

  _onConfirmSelection() {
    List<MultiSelectOption> selectedOptions = widget.options.where((element) => element.isSelected).toList();
    Get.back(result: selectedOptions);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        child: Column(
      children: [
        Container(
          padding: EdgeInsets.symmetric(horizontal: 32),
          child: Row(
            children: [
              Text(
                widget.title,
                style: TextStyle(color: Color(0xFF222222), fontSize: 16, fontWeight: FontWeight.bold),
              ),
              GestureDetector(
                onTap: () {
                  Get.back();
                },
                child: Container(
                  margin: EdgeInsets.symmetric(vertical: 12),
                  child: Icon(
                    Icons.close,
                    size: 24,
                  ),
                ),
              )
            ],
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
          ),
        ),
        Expanded(
            child: ListView.builder(
          itemBuilder: (BuildContext ctx, int idx) {
            return _makeListItem(widget.options[idx], idx);
          },
          itemCount: widget.options.length,
        )),
        SafeArea(
            child: Container(
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 10),
          decoration: BoxDecoration(border: Border(top: BorderSide(color: Color(0xFFF0F1F4)))),
          child: Container(
            height: 40,
            child: ElevatedButton(
              style: ElevatedButton.styleFrom(primary: widget.themeColor),
              child: Text('confirm'.tr, style: TextStyle(color: Colors.white)),
              onPressed: _onConfirmSelection,
            ),
          ),
        ))
      ],
      crossAxisAlignment: CrossAxisAlignment.stretch,
    ));
  }
}
