import 'package:flutter/material.dart';

class MultilineTextInput extends StatelessWidget {
  final int maxLine;
  final String? placeholder;
  final TextEditingController? textEditingController;
  final String? errorText;
  final Function(String)? onChanged;

  const MultilineTextInput({
    this.maxLine = 2,
    this.placeholder,
    this.textEditingController,
    this.errorText,
    this.onChanged,
  });

  @override
  Widget build(BuildContext context) {
    bool hasError = errorText != null;
    return Column(
      children: [
        Container(
          padding: EdgeInsets.only(left: 8, right: 8, bottom: 8),
          decoration: BoxDecoration(border: Border.all(color: hasError ? Colors.red : Color(0xFFE7E7E7)), borderRadius: BorderRadius.circular(8)),
          child: TextField(
            maxLines: maxLine,
            controller: textEditingController,
            maxLength: 255,
            onChanged: onChanged,
            decoration: InputDecoration(contentPadding: EdgeInsets.zero, hintText: placeholder, border: InputBorder.none),
          ),
        ),
        Visibility(
          child: Container(
            padding: EdgeInsets.only(top: 3),
            child: Text(
              errorText ?? '',
              style: TextStyle(color: Color(0xFFE51C23)),
            ),
          ),
          visible: hasError,
        )
      ],
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.stretch,
    );
  }
}
