import 'package:flutter/material.dart';

class NormalInputAndMarkWidget extends StatelessWidget {
  final Color backgroundColor;
  final double space;
  final EdgeInsets padding;
  final bool isRequired;
  final double requiredIndent;
  final bool marked;
  final Color markLineColor;
  final Color normalLineColor;
  final double? lineIndent;
  final double? lineEndIndent;
  final bool showErrorTips;
  final String errorTipsText; //errorTips 不为空时，该值无效
  final Widget left;
  final Widget right;
  final Widget? errorTips;

  const NormalInputAndMarkWidget({
    Key? key,
    this.backgroundColor = Colors.white,
    this.space = 20,
    this.padding = const EdgeInsets.symmetric(vertical: 16),
    this.isRequired = false,
    this.requiredIndent = 0,
    this.marked = false,
    this.markLineColor = const Color(0xFFE51C23),
    this.normalLineColor = const Color(0xFFF3F4F7),
    this.lineIndent,
    this.lineEndIndent,
    this.showErrorTips = false,
    this.errorTipsText = '',
    required this.left,
    required this.right,
    this.errorTips,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: backgroundColor,
      child: Column(
        children: [
          Container(
            alignment: Alignment.center,
            padding: padding,
            child: Row(
              children: [
                left,
                SizedBox(width: requiredIndent),
                Visibility(visible: isRequired, child: Text('*', style: TextStyle(color: Color(0xFFE53225), fontSize: 15))),
                VerticalDivider(width: space, color: Colors.transparent),
                Expanded(child: right),
              ],
            ),
          ),
          Visibility(
            visible: marked,
            child: Divider(height: 1, color: markLineColor, indent: lineIndent, endIndent: lineEndIndent),
            replacement: Divider(height: 1, color: normalLineColor, indent: lineIndent, endIndent: lineEndIndent),
          ),
          Visibility(
            visible: showErrorTips,
            child: errorTips ?? _defaultErrorTips,
          ),
        ],
      ),
    );
  }

  Widget get _defaultErrorTips {
    return Container(
      alignment: Alignment.centerLeft,
      padding: EdgeInsets.fromLTRB(lineIndent ?? 0, 2, lineEndIndent ?? 0, 2),
      child: Text(errorTipsText, style: TextStyle(fontSize: 12, color: Color(0xFFE51C23))),
    );
  }

}
