import 'dart:typed_data';
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:native_pdf_view/native_pdf_view.dart';
import 'package:jm_basic_flutter/utils/toast_util.dart';

class PDFScreen extends StatefulWidget {
  _PDFScreen createState() => _PDFScreen();
}

class _PDFScreen extends State<PDFScreen> {
  Uint8List? _pdfData;
  String _path = '';
  // int _actualPageNumber = 1;
  // int _allPagesCount = 0;
  late PdfController _pdfController;

  @override
  void initState() {
    super.initState();

    if (Get.arguments != null) {
      _path = Get.arguments['path'] ?? '';
    }

    if (_isNetFile()) {
      _getPdfData(_path);
      _pdfController = PdfController(
        document: PdfDocument.openData(_pdfData!),
      );
    } else {
      _pdfController = PdfController(
        document: PdfDocument.openFile(_path),
      );
    }
  }

  @override
  void dispose() {
    cancelToken.cancel();
    _pdfData = null;
    _pdfController.dispose();
    super.dispose();
  }

  bool _isNetFile() {
    return _path.startsWith('http') || _path.startsWith('https');
  }

  Widget _makePdfView() {
    if (_pdfData == null) {
      return Container(
        child: Text(''),
          width: 0,
          height: 0
      );
    } else {
      return PdfView(
        controller: _pdfController,
        scrollDirection: Axis.vertical,
        onDocumentLoaded: (document) {
          setState(() {
            // _actualPageNumber = 1;
            // if (document != null) {
            //   _allPagesCount = document.pagesCount;
            // } else {
            //   _allPagesCount = 0;
            // }
          });
        },
        onPageChanged: (page) {
          setState(() {
            // _actualPageNumber = page;
          });
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('PDF'),
        brightness: Brightness.light,
        backgroundColor: Colors.white,
      ),
      body: _makePdfView(),
    );
  }

  final CancelToken cancelToken = CancelToken() ;

  _getPdfData(String path) async {
    try {
      ToastUtil.showLoading(clickClose: true);
      var response = await Dio().get(path, options: Options(responseType: ResponseType.bytes),cancelToken:cancelToken );
      setState(() {
        _pdfData = response.data;
        _pdfController = PdfController(
          document: PdfDocument.openData(_pdfData!),
        );
      });
    } catch (e, s) {
      debugPrint("Pdf_Dio：$e\n$s");
    } finally {
      ToastUtil.dismiss();
    }
  }
}
