import 'dart:io';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:image_pickers/image_pickers.dart';
import 'package:get/get.dart';
import 'pick_image_dialog.dart';

class PickAndDisplayImagesGrid extends StatefulWidget {
  final List<dynamic> imageList;
  final Function(List<Media>) onPickingImages;
  final Function(int) onRemoveAtIndex;
  final int maximumImageCount;
  final int numberOfColumns;

  const PickAndDisplayImagesGrid({
    required this.onPickingImages,
    required this.imageList,
    required this.onRemoveAtIndex,
    this.maximumImageCount = 9,
    this.numberOfColumns = 4,
  });

  @override
  _PickAndDisplayImagesGridState createState() => _PickAndDisplayImagesGridState();
}

class _PickAndDisplayImagesGridState extends State<PickAndDisplayImagesGrid> {
  _onPickNewImage() async {
    FocusManager.instance.primaryFocus!.unfocus();
    List<Media>? images = await showCupertinoModalPopup(
        context: Get.context!,
        builder: (BuildContext ctx) {
          return PickImageDialog(
            maxImageCount: widget.maximumImageCount - widget.imageList.length,
          );
        });
    if (images != null) {
      /// 图片选择框架有bug，会偶现图片路径文件不存在的情况，先检查文件是否存在，再返回
      if (widget.onPickingImages != null) {
        List<Media> checkedImageLit = [];
        images.forEach((element) {
          if (File(element.path!).existsSync()) {
            checkedImageLit.add(element);
          }
        });
        widget.onPickingImages(checkedImageLit);
      }
    }
  }

  Widget makeTakePhotoButton() {
    return RawMaterialButton(
      onPressed: _onPickNewImage,
      fillColor: Colors.white,
      elevation: 0,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(4)),
      child: Container(
        // height: 78,
        // width: 78,
        child: Stack(
          children: [
            Positioned.fill(
                child: Image.asset(
              'assets/images/'
                  'picture_bg.png',
              fit: BoxFit.fill,
            )),
            Positioned.fill(child: Icon(Icons.camera_alt_outlined, size: 24, color: Color(0xFF777777)))
          ],
        ),
      ),
    );
  }

  Widget makeImageCell(int idx) {
    var image = widget.imageList[idx];
    return Container(
      clipBehavior: Clip.none,
      width: 78,
      height: 78,
      decoration: BoxDecoration(border: Border.all(color: Color(0xFFCCCCCC)), borderRadius: BorderRadius.circular(5)),
      child: Stack(
        clipBehavior: Clip.none,
        children: [
          Positioned.fill(
              child: Container(
            clipBehavior: Clip.hardEdge,
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(4),
              color: Color(0xFFF5F5F5),
            ),
            child: image is Media
                ? Image.file(
                    File(image.path!),
                    fit: BoxFit.cover,
                  )
                : Image.network(
                    image,
                    fit: BoxFit.cover,
                  ),
          )),
          Positioned(
            top: -10,
            right: -10,
            child: GestureDetector(
              onTap: () {
                if (widget.onRemoveAtIndex != null) {
                  widget.onRemoveAtIndex(idx);
                }
              },
              child: Container(
                padding: EdgeInsets.all(5),
                child: Container(
                  width: 25,
                  height: 25,
                  alignment: Alignment.center,
                  decoration: BoxDecoration(
                      border: Border.all(width: 2, color: Colors.white), color: Color(0xFF222222).withOpacity(0.9), borderRadius: BorderRadius.circular(12.5)),
                  child: Icon(
                    Icons.close,
                    size: 12,
                    color: Colors.white,
                  ),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  Widget buildItem(BuildContext ctx, int idx) {
    bool shouldDisplayPickImageButton = widget.imageList.length < widget.maximumImageCount;
    if (idx == 0 && shouldDisplayPickImageButton) {
      return makeTakePhotoButton();
    }
    return makeImageCell(shouldDisplayPickImageButton ? idx - 1 : idx);
  }

  @override
  Widget build(BuildContext context) {
    int itemLength = widget.imageList.length >= widget.maximumImageCount ? widget.maximumImageCount : widget.imageList.length + 1;
    return Container(
      child: GridView.builder(
        gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: widget.numberOfColumns, crossAxisSpacing: 12, mainAxisSpacing: 12),
        itemBuilder: buildItem,
        itemCount: itemLength,
        shrinkWrap: true,
        clipBehavior: Clip.none,
        physics: NeverScrollableScrollPhysics(),
      ),
    );
  }
}
