import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:image_pickers/image_pickers.dart';
import 'package:get/get.dart';

class PickImageDialog extends StatelessWidget {
  final int maxImageCount;
  final String? photoAlbumText;
  final String? cameraText;
  final String? cancelText;
  final Function(List<Media> pickData)? onFinished;

  PickImageDialog({
    this.maxImageCount = 9,
    this.photoAlbumText,
    this.cameraText,
    this.cancelText,
    this.onFinished,
  });

  @override
  Widget build(BuildContext context) {
    return CupertinoActionSheet(
      actions: [
        CupertinoActionSheetAction(
          child: Text(
            photoAlbumText ?? 'c_photo_album'.tr,
            style: TextStyle(color: Color(0xFF222222)),
          ),
          onPressed: () async {
            List<Media> list = await ImagePickers.pickerPaths(
              galleryMode: GalleryMode.image,
              selectCount: maxImageCount,
              showCamera: false,
              compressSize: 5000,
            );
            Navigator.of(context).pop(list);
            if (onFinished != null) {
              onFinished!(list);
            }
          },
        ),
        CupertinoActionSheetAction(
          child: Text(cameraText ?? 'c_camera'.tr, style: TextStyle(color: Color(0xFF222222))),
          onPressed: () async {
            Media? image = await ImagePickers.openCamera();
            List<Media> list = image != null ? [image] : [];
            Navigator.of(context).pop(list);
            if (onFinished != null) {
              onFinished!(list);
            }
          },
        ),
      ],
      cancelButton: CupertinoActionSheetAction(
        onPressed: () async {
          Navigator.of(context).pop();
        },
        child: Text(cancelText ?? 'cancel'.tr),
      ),
    );
  }
}
