import 'package:flutter/material.dart';
import 'never_focusable_focus_node.dart';

class TextInputSearchField extends StatefulWidget {
  final double height;
  final String placeholder;
  final bool highlightOnFocus;
  final Widget? icon;
  final Widget? trailingIcon;
  final VoidCallback? onTap;
  final bool disabled;
  final VoidCallback? onClearText;
  final TextEditingController textEditingController;
  final bool autoFocus;

  TextInputSearchField({
    this.height = 35,
    this.placeholder = '',
    this.highlightOnFocus = true,
    this.icon,
    this.onTap,
    bool disabled = false,
    this.onClearText,
    required this.textEditingController,
    this.trailingIcon,
    this.autoFocus = false,
  }) : this.disabled = disabled ? true : onTap != null;

  @override
  _TextInputSearchFieldState createState() => _TextInputSearchFieldState();
}

class _TextInputSearchFieldState extends State<TextInputSearchField> {
  FocusNode? _focusNode;
  bool highlight = false;
  bool clearIconShouldDisplay = false;

  @override
  void initState() {
    super.initState();
    if (!widget.disabled) {
      _focusNode = FocusNode();
    } else {
      _focusNode = NeverFocusableFocusNode();
    }
    _focusNode!.addListener(() {
      setState(() {
        highlight = _focusNode!.hasFocus && widget.highlightOnFocus;
      });
    });
    widget.textEditingController.addListener(() {
      clearIconShouldDisplay = widget.textEditingController.text.isNotEmpty;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: widget.height,
      padding: EdgeInsets.symmetric(horizontal: 6),
      decoration: BoxDecoration(borderRadius: BorderRadius.circular(4), border: Border.all(color: highlight ? Color(0xFFEC6D20) : Color(0xFFE7E7E7))),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Visibility(
            visible: widget.icon != null,
            child: Container(
              alignment: Alignment.center,
              margin: EdgeInsets.only(right: 5),
              child: widget.icon,
            ),
          ),
          Flexible(
            child: TextField(
              controller: widget.textEditingController,
              maxLines: 1,
              focusNode: _focusNode,
              onTap: widget.onTap,
              autofocus: widget.autoFocus,
              decoration: InputDecoration(
                  hintText: widget.placeholder, border: InputBorder.none, focusedBorder: InputBorder.none, contentPadding: EdgeInsets.only(bottom: 18)),
            ),
          ),
          Visibility(
            child: RawMaterialButton(
              constraints: BoxConstraints(),
              onPressed: () {
                widget.textEditingController.clear();
                if (widget.onClearText != null) {
                  widget.onClearText!();
                }
              },
              materialTapTargetSize: MaterialTapTargetSize.shrinkWrap,
              child: Icon(
                Icons.highlight_remove,
                color: Color(0xFFA1A1A1),
                size: 22,
              ),
            ),
            visible: clearIconShouldDisplay,
          ),
          Visibility(
            child: Container(
              padding: EdgeInsets.only(left: 5),
              child: widget.trailingIcon,
            ),
            visible: widget.trailingIcon != null,
          )
        ],
      ),
    );
  }
}
